.. _links:

Links
=====

Below links relevant to Stetl.

.. [GDALOGR] GDAL/OGR, http://gdal.org
.. [lxml] lxml, http://lxml.de
.. [Deegree] Deegree, http://www.deegree.org
.. [INSPIRE] INSPIRE, http://inspire.ec.europa.eu/
.. [INSPIRE-FOSS] INSPIRE FOSS project, http://inspire-foss.org
.. [PostGIS] PostGIS/PostgreSQL, http://postgis.refractions.net
.. [Slideshare] Several presentations on Stetl, http://www.slideshare.net/justb4

